# Generated by Django 3.1 on 2020-09-11 00:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('helpme', '0005_auto_20200908_2229'),
    ]

    operations = [
        migrations.RenameField(
            model_name='category',
            old_name='excluded_sites',
            new_name='category_excluded_sites',
        ),
        migrations.RenameField(
            model_name='category',
            old_name='sites',
            new_name='category_sites',
        ),
        migrations.RemoveField(
            model_name='ticket',
            name='history',
        ),
        migrations.AlterField(
            model_name='team',
            name='global_team',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='team',
            name='sites',
            field=models.ManyToManyField(to='sites.Site'),
        ),
    ]
